**What does your PR do?**

A short description of the changes made.

**What issue does this PR address**

Describe the problem that this PR solves.

Link to a specific Issue if there is one.

**Testing**

All PRs will be run against gliderad2cp's [automated tests](https://github.com/bastienqueste/gliderad2cp/blob/main/.github/workflows/tests.yml)

If the PR adds new functionality, add a test to cover it.
